package net.knarcraft.ffmpegconverter.converter;

import net.knarcraft.ffmpegconverter.streams.AudioStream;
import net.knarcraft.ffmpegconverter.streams.StreamObject;
import net.knarcraft.ffmpegconverter.utility.FFMpegHelper;

import java.io.File;
import java.util.List;

/**
 * A converter for converting audio files
 */
public class AudioConverter extends AbstractConverter {

    /**
     * Instantiates a new audio converter
     *
     * @param ffprobePath  <p>Path/command to ffprobe.</p>
     * @param ffmpegPath   <p>Path/command to ffmpeg.</p>
     * @param newExtension <p>The extension of the new file.</p>
     */
    public AudioConverter(String ffprobePath, String ffmpegPath, String newExtension) {
        super(newExtension);
        this.ffprobePath = ffprobePath;
        this.ffmpegPath = ffmpegPath;
    }

    @Override
    public String[] generateConversionCommand(String executable, File file, List<StreamObject> streams, String outFile) {
        List<String> command = FFMpegHelper.getFFMpegGeneralFileCommand(executable, file.getName());
        if (this.debug) {
            FFMpegHelper.addDebugArguments(command, 50, 120);
        }

        //Gets the first audio stream from the file and adds it to the output file
        AudioStream audioStream = getFirstAudioStream(filterStreamsByType(streams, AudioStream.class));
        FFMpegHelper.addAudioStream(command, audioStream, false);
        command.add(outFile);

        return command.toArray(new String[0]);
    }

    @Override
    public String[] getValidFormats() {
        return audioFormats;
    }
}